@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 from __future__ import absolute_import, division, print_function, unicode_literals
 
-import warnings
 from copy import copy
 
 
@@ -43,25 +42,16 @@ class Signal(object):
     __isub__ = remove
     __unhandle__ = remove
 
-    def fire(self, *args, **kwargs):
+    def fire(self, **kwargs):
         """Execute all handlers associated with this Signal.
 
-        .. warning::
-
-            Passing positional arguments is deprecated.
-
         You can also call signal object to get the same result::
 
             signal = Signal()
             signal()  # calls the signal handler
         """
-        if args:
-            warnings.warn(
-                'Firing events using positional arguments is deprecated, please use keyword arguments',
-                DeprecationWarning, stacklevel=3)
-
         for handler in copy(self._handlers):
-            handler(*args, **kwargs)
+            handler(**kwargs)
 
     __call__ = fire
 
