@@ -39,7 +39,7 @@ class StreamingAPIClient(object):
 
     Provides a simple interface wrapping the protobufs.
     """
-    CALLBACKS = _ETO_PAYLOAD_TYPES.values() + _SETO_PAYLOAD_TYPES.values()
+    CALLBACKS = list(_ETO_PAYLOAD_TYPES.values()) + list(_SETO_PAYLOAD_TYPES.values())
 
     logger = logging.getLogger(__name__ + '.SETOClient')
 
@@ -81,7 +81,7 @@ class StreamingAPIClient(object):
     def output_buffer_size(self):
         return self.session.output_buffer_size
 
-    def read(self, read_mode=READ_MODE_BUFFER_AND_DISPATCH, limit=sys.maxint):
+    def read(self, read_mode=READ_MODE_BUFFER_AND_DISPATCH, limit=sys.maxsize):
         """
         .. note::
             This method will block until it can read *any* data from the remote endpoint. It doesn't mean
@@ -152,9 +152,10 @@ class StreamingAPIClient(object):
         """
         self.session.send()
 
-    def _dispatch(self, message):
+    def _dispatch(self, frame):
         "Dispatch a frame to the callbacks"
-        name = _SETO_PAYLOAD_TYPES.get(message.type)
+        message = frame.protobuf
+        name = _SETO_PAYLOAD_TYPES.get(message.type, 'seto.unknown')
         if name == 'seto.eto':
             name = _ETO_PAYLOAD_TYPES.get(message.eto_payload.type)
         if name in self.callbacks:
@@ -164,7 +165,8 @@ class StreamingAPIClient(object):
                 callback(message=message)
             else:
                 self.logger.error("no callback %s", name)
+        else:
             self.logger.debug("ignoring unknown message: %s", name)
 
         self.logger.debug('Dispatching global callbacks for %s', name)
-        self.global_callback(name=name, message=message)
+        self.global_callback(name=name, message=frame)
