@@ -6,6 +6,7 @@
 import logging
 import socket
 import ssl
+from collections import namedtuple
 
 from google.protobuf.text_format import MessageToString
 
@@ -21,10 +22,12 @@ class SessionSettings(object):
 
     "Encapsulate settings necessary to create a new session"
 
-    def __init__(self, username, password, host='api-sandbox.smarkets.com', port=3801, ssl=True,
+    def __init__(self, username=None, password=None, token=None,
+                 host='stream.smarkets.com', port=3801, ssl=True,
                  socket_timeout=30, ssl_kwargs=None, tcp_nodelay=True):
         self.username = username
         self.password = password
+        self.token = token
         self.host = host
         self.port = port
         self.socket_timeout = socket_timeout
@@ -38,6 +41,10 @@ class SessionSettings(object):
         self.read_chunksize = 65536  # 64k
 
 
+class Frame(namedtuple('Frame', 'bytes protobuf')):
+    pass
+
+
 class Session(object):
 
     "Manages TCP communication via Smarkets streaming API"
@@ -88,8 +95,11 @@ class Session(object):
             login.Clear()
             login.type = seto.PAYLOAD_LOGIN
             login.eto_payload.type = eto.PAYLOAD_LOGIN
-            login.login.username = self.settings.username
-            login.login.password = self.settings.password
+            if self.settings.token:
+                login.login.cookie = self.settings.token.encode('utf-8')
+            else:
+                login.login.username = self.settings.username
+                login.login.password = self.settings.password
             self.logger.info("sending login payload")
             if self.account_sequence is not None:
                 self.logger.info("Attempting to resume session, account sequence %d",
@@ -155,7 +165,7 @@ class Session(object):
 
         :return: A payload or None if no payloads in buffer.
 
-        :rtype: :class:`smarkets.streaming_api.seto.Payload` or None
+        :rtype: :class:`smarkets.streaming_api.session.Frame` or None
 
         """
         if not self.buffered_incoming_payloads:
@@ -167,11 +177,12 @@ class Session(object):
         payload = seto.Payload()
         payload.ParseFromString(bytes(data))
         self._handle_in_payload(payload)
+        frame = Frame(bytes=data, protobuf=payload)
         if payload.eto_payload.seq == self.inseq:
             # Go ahead
             self.logger.debug("received sequence %d", self.inseq)
             self.inseq += 1
-            return payload
+            return frame
         elif payload.eto_payload.seq > self.inseq:
             self.logger.warn(
                 'Received incoming sequence %d instead of expected %d',
